package com.link.core.basic.aop;

import com.link.base.user.model.CoreUser;
import com.link.core.basic.annotations.Permission;
import com.link.core.basic.service.BasicServiceException;
import com.link.core.util.ReflectUtil;
import com.link.core.util.StringUtils;
import com.link.core.util.UserUtil;
import java.util.HashMap;
import java.util.Map;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.Signature;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.stereotype.Component;

@Component
@Aspect
public class PermissionAspect {
   @Pointcut("execution(* com.link.*.*.*.controller.*.*(..)) || execution(* com.link.core.basic.controller.*.*(..))")
   public void pointcutMethod() {
   }

   @Around("pointcutMethod()")
   public Object beforeMethod(ProceedingJoinPoint point) throws Throwable {
      try {
         String userPass = null;
         String userFail = null;
         Boolean disabled = false;
         Boolean resPassFlag = true;
         Boolean resFailFlag = true;
         Signature signature = point.getSignature();
         Boolean methodflag = ((MethodSignature)signature).getMethod().isAnnotationPresent(Permission.class);
         if (methodflag) {
            disabled = ((Permission)((MethodSignature)signature).getMethod().getAnnotation(Permission.class)).disabled();
            if (!disabled) {
               userPass = ((Permission)((MethodSignature)signature).getMethod().getAnnotation(Permission.class)).userPass();
               userFail = ((Permission)((MethodSignature)signature).getMethod().getAnnotation(Permission.class)).userFail();
            }
         } else {
            Object targetObj = point.getTarget();
            Boolean classFlag = targetObj.getClass().isAnnotationPresent(Permission.class);
            if (classFlag) {
               disabled = ((Permission)targetObj.getClass().getAnnotation(Permission.class)).disabled();
               if (!disabled) {
                  userPass = ((Permission)targetObj.getClass().getAnnotation(Permission.class)).userPass();
                  userFail = ((Permission)targetObj.getClass().getAnnotation(Permission.class)).userFail();
               }
            }
         }

         if (!disabled) {
            CoreUser currentUser = UserUtil.getUser();
            if (!StringUtils.isBlank(userFail) && !this.checkUserFail(currentUser, userFail)) {
               resFailFlag = false;
            }

            if (!StringUtils.isBlank(userPass) && !this.checkUserPass(currentUser, userPass)) {
               resPassFlag = false;
            }
         }

         if (resFailFlag && resPassFlag) {
            return point.proceed();
         } else {
            Map<String, Object> result = new HashMap(2);
            result.put("message", "没有访问权限，请联系管理员！");
            result.put("success", false);
            return result;
         }
      } catch (Exception var11) {
         Exception e = var11;
         e.printStackTrace();
         throw new BasicServiceException(e);
      }
   }

   private Boolean checkUserPass(CoreUser user, String conditionValue) throws Exception {
      Boolean canPass = false;
      String[] neValues = conditionValue.split(";");
      String[] var5 = neValues;
      int var6 = neValues.length;

      for(int var7 = 0; var7 < var6; ++var7) {
         String neValue = var5[var7];
         String[] fieldValue = neValue.split(":");
         if (fieldValue.length == 1) {
            throw new Exception("注解条件维护格式有误！");
         }

         Object currentValue = ReflectUtil.invokeGetterNew(user, fieldValue[0]);
         String[] values = fieldValue[1].substring(1, fieldValue[1].length() - 1).split(",");
         String[] var12 = values;
         int var13 = values.length;

         for(int var14 = 0; var14 < var13; ++var14) {
            String value = var12[var14];
            if (currentValue == null) {
               if (value.equals("null")) {
                  canPass = true;
                  break;
               }
            } else if (currentValue.toString().equals(value)) {
               canPass = true;
               break;
            }
         }
      }

      return canPass;
   }

   private Boolean checkUserFail(CoreUser user, String conditionValue) throws Exception {
      Boolean canPass = true;
      String[] neValues = conditionValue.split(";");
      String[] var5 = neValues;
      int var6 = neValues.length;

      for(int var7 = 0; var7 < var6; ++var7) {
         String neValue = var5[var7];
         String[] fieldValue = neValue.split(":");
         if (fieldValue.length == 1) {
            throw new Exception("注解条件维护格式有误！");
         }

         Object currentValue = ReflectUtil.invokeGetterNew(user, fieldValue[0]);
         String[] values = fieldValue[1].substring(1, fieldValue[1].length() - 1).split(",");
         String[] var12 = values;
         int var13 = values.length;

         for(int var14 = 0; var14 < var13; ++var14) {
            String value = var12[var14];
            if (currentValue == null) {
               if (value.equals("null")) {
                  canPass = false;
                  break;
               }
            } else if (currentValue.toString().equals(value)) {
               canPass = false;
               break;
            }
         }
      }

      return canPass;
   }
}
